@extends('master.app')
@section('title', 'Report')
@section('pageCSS')
    <style id="table_style">
        table {
            width: 100%;
            border-collapse: collapse;
            margin: auto;
            border: 0.2px solid black;
        }

        td,
        th {
            border: 0.5px solid black;
            text-align: center;
        }

        td {
            font-size: 12px;
            padding: 0px;

            height: 15px;
            text-align: center;
        }

        .report-logo {
            margin-left: 480px;
            height: 100px;
            width: 100px;
            padding-top: 0px;
            margin-bottom: 0px;
        }

        h6 {
            padding: 0px;
            margin: 0px;
        }

        p {
            padding: 0px;
            margin: 0px;
        }
    </style>
@endsection
@section('body')
    <main class="app-content">
        <div class="card">
            <div class="card-body">
                <div class="row">
                    <div class="card">
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-3 mb-4">
                                    <select id="type_id" type="text"
                                        class="form-control select2 @error('type_id') is-invalid @enderror" name="type_id"
                                        required>
                                        <option value="">Choose Types</option>
                                        <option value="1">Advance </option>
                                        <option value="2">Overtime</option>
                                        <option value="3">Attendance </option>
                                        <option value="4">Salary </option>
                                        <option value="5">Balances</option>
                                        <option value="6">List</option>
                                    </select>
                                    @error('type_id')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="col-md-3 mb-4" id="emp_box">
                                    <select id="employee_id" type="text"
                                        class="form-control select2 @error('employee_id') is-invalid @enderror"
                                        name="employee_id" required>
                                        <option value="">Choose employees</option>
                                        <option value="all">All</option>
                                        @foreach ($employees as $row)
                                            <option value="{{ $row->id }}">
                                                {{ 'Name ' . $row->name . ' phone ' . $row->phone }}</option>
                                        @endforeach
                                    </select>
                                    @error('employee_id')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="col-md-3 mb-4">
                                    @if ($bdate == 1)
                                        <input type="text" required dir="rtl" name="fromDate" value=""
                                            class="form-control sample-date-picker" id="fromDate" />
                                        <label class="form-label" for="fromDate">From Date</label>
                                    @else
                                        <div class="form-outline datepicker">
                                            <input type="date" required name="fromDate" value="{{ date('Y-m-d') }}"
                                                class="form-control " id="fromDate" />
                                            <label class="form-label" for="fromDate">From Date</label>
                                        </div>
                                    @endif

                                </div>
                                <div class="col-md-3 mb-4">
                                    @if ($bdate == 1)
                                        <input type="text" required dir="rtl" name="toDate" value=""
                                            class="form-control sample-date-picker" id="toDate" />
                                        <label class="form-label" for="toDate">To Date</label>
                                    @else
                                        <div class="form-outline datepicker">
                                            <input type="date" required name="toDate" value="{{ date('Y-m-d') }}"
                                                class="form-control " id="toDate" />
                                            <label class="form-label" for="toDate">To Date</label>
                                        </div>
                                    @endif

                                </div>

                                <div class="col-md-12 mt-4">
                                    <button class="btn btn-primary btn-rounded btn-sm" id="btn-find">Find</button>
                                    <button class="btn btn-primary btn-rounded btn-sm" id="btn-print"
                                        onclick="PrintTable();">Print</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row mt-4">
                    <div class="col-md-12">
                        <div class="card-body p-4 print_div" id="print_div">

                        </div>
                    </div>
                </div>
            </div>
        </div>
    </main>
@endsection
@section('pageJs')
    <script type="text/javascript">
        $(".app-menu").removeClass("active");
        $("#nav_hri").addClass("active");
        $("#hri").addClass("is-expanded");
        $("#nav_emp_account").addClass("active");
    </script>
    <script>
        $("#type_id").change(function() {
            if ($("#type_id").val() == 6) {
                $("#emp_box").hide();
                $("#from_box").hide();
                $("#to_box").hide();
            } else {
                $("#emp_box").show();
                $("#from_box").show();
                $("#to_box").show();
            }

        });
        $("#btn-find").click(function() {

            var employee_id = $("#employee_id").val();
            var type_id = $("#type_id").val();
            var month_id = $("#month_id").val();
            if (type_id != 6) {
                if (type_id == "") {
                    alert('Select Report type');
                    return false;
                }

                if (employee_id == "") {
                    alert('Select employee');
                    return false;
                }
            }



            $.ajax({
                url: '{{ route('employee.report_find') }}',
                type: 'GET',
                data: {
                    'fromDate': $("#fromDate").val(),
                    'toDate': $("#toDate").val(),
                    'employee_id': $("#employee_id").val(),
                    'type_id': $("#type_id").val(),
                },
                success: function(data) {
                    $(".print_div").html(data);
                },
                error: function() {
                    swal("Warrning", "Error occured!", "error");
                },
            });
        });
    </script>
@endsection
