@extends('master.app')
@section('title', 'Stock')
@section('body')
    <main class="app-content">
        <div class="card">
            <div class="card-header">
                <h4>Stock</h4>
                @if ($errors->any())
                    @foreach ($errors->all() as $error)
                        <div>{{ $error }}</div>
                    @endforeach
                @endif
                @include('general.valert')

            </div>
            <div class="card-body">
                <form action="{{ route('stocks.update', $data->id) }}" method="post">
                    @method('PUT')
                    @csrf
                    <div class="row mb-3">
                        <div class="col-md-4">
                            <select id="category_id" type="text"
                                class="form-control select2 @error('category_id') is-invalid @enderror" required
                                name="category_id">
                                <option value="">Choose Category</option>
                                @foreach ($categories as $row)
                                    <option value="{{ $row->id }}"
                                        @if ($data->cat_id == $row->id) {{ 'selected' }} @endif>{{ $row->title_ps }}
                                    </option>
                                @endforeach
                            </select>
                            @error('category_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                        <div class="col-md-4">
                            <select id="subcategory_id" type="text" class="form-control select2" name="subcategory_id">
                                <option value="{{ $data->sub_cat_id }}">{{ $data->sub_category->title_en }}</option>

                            </select>
                        </div>
                        <div class="col-md-4">
                            <select id="location_id" type="text"
                                class="form-control select2 @error('location_id') is-invalid @enderror" required
                                name="location_id">
                                <option value="">Choose Location</option>
                                @foreach ($location as $row)
                                    <option value="{{ $row->id }}"
                                        @if ($row->id == $data->location_id) {{ 'selected' }} @endif>{{ $row->title_ps }}
                                    </option>
                                @endforeach
                            </select>
                            @error('location_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>

                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <select id="unit_id" type="text"
                                class="form-control select2 @error('unit_id') is-invalid @enderror" required name="unit_id">
                                <option value="">Choose Unit Type</option>
                                @foreach ($units as $row)
                                    <option value="{{ $row->id }}"
                                        @if ($data->unit_id == $row->id) {{ 'selected' }} @endif>{{ $row->title_ps }}
                                    </option>
                                @endforeach
                            </select>
                            @error('unit_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                        <div class="col-md-6">
                            <select id="weight_id" type="text"
                                class="form-control select2 @error('weight_id') is-invalid @enderror" required
                                name="weight_id">
                                <option value="">Choose Weight</option>
                                @foreach ($weights as $row)
                                    <option value="{{ $row->id }}"
                                        @if ($data->weight_id == $row->id) {{ 'selected' }} @endif>{{ $row->title_ps }}
                                    </option>
                                @endforeach
                            </select>
                            @error('weight_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                    </div>
                    <div class="row mt-3">
                        <div class="col-md-3">
                            <!-- Text input -->
                            <div class="form-outline mb-3">
                                <input type="number" id="qty" name="qty" required
                                    value="{{ old('qty') ?? $data->qty }}" class="form-control" />
                                <label class="form-label" for="qty">QTY</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-outline mb-3">
                                <input type="number" id="cost_price" name="cost_price" required
                                    value="{{ old('cost_price') ?? $data->cpi }}" class="form-control" />
                                <label class="form-label" for="cost_price">Cost Price</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-outline mb-3">
                                <input type="number" id="sale_price" name="sale_price" required
                                    value="{{ old('sale_price') ?? $data->spi }}" class="form-control" />
                                <label class="form-label" for="sale_price">Sale price</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <select id="currency_id" type="text"
                                class="form-control select2 @error('currency_id') is-invalid @enderror" required
                                name="currency_id">
                                <option value="">Choose Currency</option>
                                @foreach ($currencies as $row)
                                    <option value="{{ $row->id }}" @if($data->currency_id==$row->id) {{ "selected" }} @endif>{{ $row->title_ps }}</option>
                                @endforeach
                            </select>
                            @error('currency_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                    </div>
                    <button type="submit" class="btn btn-primary btn-rounded mb-3">Save</button>
                </form>
            </div>
        </div>
    </main>
@endsection


@section('pageJs')
    <script type="text/javascript">
        $(".app-menu").removeClass("active");
        $("#nav_stocki").addClass("active");
        $("#stocki").addClass("is-expanded");
        $("#stock_history").addClass("active");
        $(document).on('change', '#category_id', function() {
            $.ajax({
                url: '{{ route('category.get') }}',
                type: 'GET',
                data: {
                    'p_category': $(this).val(),
                },
                success: function(data) {

                    $("#subcategory_id").html(data);
                },
                error: function() {
                    swal("Warrning", "Error occured!", "error");
                },
            });
        });
    </script>
@endsection
