@extends('master.app')
@section('title', 'Stock')
@section('body')
    <main class="app-content">
        <div class="card">
            <div class="card-header">
                <h4>Add</h4>
                @if ($errors->any())
                    @foreach ($errors->all() as $error)
                        <div>{{ $error }}</div>
                    @endforeach
                @endif
                @include('general.valert')

            </div>
            <div class="card-body">
                <form action="{{ route('rstockprocess.store') }}" method="post" id="myform">
                    @method('post')
                    @csrf
                    <div class="row">
                        <div class="col-md-4 mt-3">
                            <select id="cat_id" type="text"
                                class="form-control select2 @error('cat_id') is-invalid @enderror" required name="cat_id">
                                <option value="">Choose Category</option>
                                @foreach ($categories as $row)
                                    <option value="{{ $row->id }}">{{ $row->title_en }}</option>
                                @endforeach
                            </select>
                            @error('cat_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                        <div class="col-md-4 mt-3">
                            <select id="scat_id" type="text"
                                class="form-control select2 @error('scat_id') is-invalid @enderror" 
                                name="scat_id">
                                <option value="">Choose Sub Category</option>
                               
                            </select>
                           
                        </div>
                       
                        <div class="col-md-4 mt-3">
                            <select id="unit_id" type="text"
                                class="form-control select2 @error('unit_id') is-invalid @enderror" required name="unit_id">
                                <option value="">Choose Unit Type</option>
                                @foreach ($units as $row)
                                    <option value="{{ $row->id }}">{{ $row->title_en }}</option>
                                @endforeach
                            </select>
                            @error('unit_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>

                       
                        <div class="col-md-6 mt-3">
                            <div class="form-outline mb-4">
                                <input type="number" readonly id="c_qty" name="c_qty" required value="{{ old('c_qty') }}"
                                    class="form-control" />
                                <label class="form-label" for="c_qty">Current Availible</label>
                            </div>
                        </div>
                        <div class="col-md-6 mt-3">
                            <div class="form-outline mb-4">
                                <input type="number" id="u_qty" name="u_qty" required value="{{ old('u_qty') }}"
                                    class="form-control" />
                                <label class="form-label" for="u_qty">How Many Used</label>
                            </div>
                        </div>
                       
                        <div class="col-md-6 mt-3" style="display: none">
                            <select id="currency_id" type="text"
                                class="form-control select2 @error('currency_id') is-invalid @enderror" required
                                name="currency_id">
                                <option value="">Choose Currency</option>
                                @foreach ($currencies as $row)
                                    <option value="{{ $row->id }}"
                                        @if ($row->id == 1) {{ 'selected' }} @endif>{{ $row->title_en }}
                                    </option>
                                @endforeach
                            </select>
                            @error('currency_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                    </div>
                    <button type="submit" class="btn btn-primary btn-rounded mt-4">Save</button>
                </form>
            </div>
        </div>
    </main>
@endsection


@section('pageJs')
    <script type="text/javascript">
        $(".app-menu").removeClass("active");
        $("#nav_stocki").addClass("active");
        $("#stocki").addClass("is-expanded");
        $("#stock_history").addClass("active");
        
        $("#myform").submit(function() {
            var cqty = $("#c_qty").val();
            var uqty = $("#u_qty").val();
          
            if (parseFloat(cqty) < parseFloat(uqty)) {
                alert("Your Take Quantity is Bigger then Stock Quantity");
                return false;
            }
        });
        $(document).on('change', '#cat_id', function() {
            $.ajax({
                url: '{{ route('category.row_category') }}',
                type: 'GET',
                data: {
                    'cat_id': $(this).val(),
                },
                success: function(data) {
                    $("#scat_id").html(data);
                },
                error: function() {
                    swal("Warrning", "Error occured!", "error");
                },
            });
        });

        $(document).on('change', '#unit_id', function() {
            $.ajax({
                url: '{{ route('row_stock.get_value') }}',
                type: 'GET',
                data: {
                    'cat_id': $("#cat_id").val(),
                    'scat_id': $("#scat_id").val(),
                    'unit_id': $("#unit_id").val(),
                },
                success: function(data) {
                    $("#c_qty").val(data);
                },
                error: function() {
                    swal("Warrning", "Error occured!", "error");
                },
            });
        });

        

    </script>
@endsection
