@extends('master.app')
@section('title', 'Stock')
@section('body')
    <main class="app-content">
        <div class="card">
            <div class="card-header">
                <h4>Add</h4>
                @if ($errors->any())
                    @foreach ($errors->all() as $error)
                        <div>{{ $error }}</div>
                    @endforeach
                @endif
                @include('general.valert')

            </div>
            <div class="card-body">
                <form action="{{ route('rstockprocess.update',$stock->id) }}" method="post">
                    @method('put')
                    @csrf
                    <div class="row mb-4">
                        <div class="col-md-6">
                            <select id="cat_id" type="text"
                                class="form-control select2 @error('cat_id') is-invalid @enderror" required name="cat_id">
                                <option value="">Choose Category</option>
                                @foreach ($categories as $row)
                                    <option value="{{ $row->id }}" @if($row->id==$stock->cat_id) {{ "selected" }} @endif>{{ $row->title_ps }}</option>
                                @endforeach
                            </select>
                            @error('cat_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                        <div class="col-md-6">
                            <select id="unit_id" type="text"
                                class="form-control select2 @error('unit_id') is-invalid @enderror" required name="unit_id">
                                <option value="">Choose Unit Type</option>
                                @foreach ($units as $row)
                                    <option value="{{ $row->id }}" @if($row->id==$stock->unit_id) {{ "selected" }} @endif>{{ $row->title_ps }}</option>
                                @endforeach
                            </select>
                            @error('unit_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                    </div>
                    <div class="row mt-3">
                        <div class="col-md-6">
                            <!-- Text input -->
                            <div class="form-outline mb-4">
                                <input type="number" id="qty"  name="qty" required value="{{ old('qty') ?? $stock->qty }}"
                                    class="form-control" />
                                <label class="form-label" for="qty">QTY</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-outline mb-4">
                                <input type="number" id="cpi" name="cpi" required value="{{ old('cpi') ?? $stock->cpi }}"
                                    class="form-control" />
                                <label class="form-label" for="cpi">Cost Price</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-outline mb-4">
                                <input type="number" id="spi" name="spi" required value="{{ old('spi') ?? $stock->spi }}"
                                    class="form-control" />
                                <label class="form-label" for="spi">Sale price</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <select id="currency_id" type="text"
                                class="form-control select2" style="display: none"
                                name="currency_id">
                                <option value="">Choose Currency</option>
                                @foreach ($currencies as $row)
                                    <option value="{{ $row->id }}" @if($row->id==$stock->currency_id) {{ "selected" }} @endif>{{ $row->title_ps }}</option>
                                @endforeach
                            </select>
                            @error('currency_id')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                    </div>
                    <button type="submit" class="btn btn-primary btn-rounded mb-4">Save</button>
                </form>
            </div>
        </div>
    </main>
@endsection


@section('pageJs')
    <script type="text/javascript">
        $(".app-menu").removeClass("active");
        $("#nav_stocki").addClass("active");
        $("#stocki").addClass("is-expanded");
        $("#stock_history").addClass("active");
        $(document).on('change', '#category_id', function() {
            $.ajax({
                url: '{{ route('category.get') }}',
                type: 'GET',
                data: {
                    'p_category': $(this).val(),
                },
                success: function(data) {

                    $("#subcategory_id").html(data);
                },
                error: function() {
                    swal("Warrning", "Error occured!", "error");
                },
            });
        });
    </script>
@endsection
