@extends('master.app')
@section('title', 'customer')
@section('body')
    <main class="app-content">
        <div class="card">
            <div class="card-body">
                <div class="row">
                    <div class="col-md-4">
                        <h4>Warning Stock</h4>
                    </div>
                    <div class="col-md-8">
                        <div class="btn-group" role="group" aria-label="Basic example" style="float: right">
                            <a href="{{ route('stock.report_show') }}"
                                class="btn btn-primary btn-rounded btn-sm">Report</a>
                            @include('general.filter-button')
                            <a href="{{ route('stock.p_transaction_report_show') }}"
                                class="btn btn-primary btn-rounded btn-sm text-light">Transaction</a>
                            <a href="{{ route('stocks.create') }}"
                                class="btn btn-primary btn-rounded btn-sm text-light">Add</a>
                        </div>
                    </div>

                </div>
                @include('stock.filter-form')
                <div class="row mt-3">
                    <div class="col-md-12">
                        <table class="table table-striped  dt-responsive"
                            style="border-collapse: collapse; border-spacing: 0;">
                            <thead>
                                <tr>
                                    <th scope="col">#</th>
                                    <th scope="col">Cat</th>
                                    <th scope="col">Sub/Cat</th>
                                    <th scope="col">Unit</th>
                                    <th scope="col">Weight</th>
                                    <th scope="col">SPI</th>
                                    <th scope="col">CPI</th>
                                    <th scope="col">QTY</th>
                                    <th scope="col">Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($stock as $row)
                                    <tr class="fw-normal">
                                        <th class="border-0">{{ $loop->iteration }}</th>
                                        <td class="border-0 align-middle">{{ $row->category->title_ps }}
                                        </td>
                                        <td class="border-0 align-middle">{{ $row->sub_category->title_ps }}
                                        </td>
                                        <td class="border-0 align-middle">
                                            {{ $row->unit->title_ps }}</td>
                                        <td class="border-0 align-middle">
                                            <h6 class="mb-0"><span
                                                    class="badge bg-success">{{ $row->weight->title_ps }}</span>
                                            </h6>
                                        </td>
                                        <td class="border-0 align-middle">{{ $row->spi }}
                                        </td>
                                        <td class="border-0 align-middle">{{ $row->cpi }}
                                        </td>
                                        <td class="border-0 align-middle"><span class="badge badge-warning text-light">{{ $row->qty }}</span></td>

                                        <td class="border-0 align-middle">
                                            <a href="{{ route('stocks.edit', $row->id) }}" data-mdb-toggle="tooltip"
                                                title="Edit"><i class="fas fa-pencil fa-lg text-success me-3"></i></a>


                                        </td>
                                    </tr>
                                @endforeach
                                
                            </tbody>
                        </table>
                    </div>
                </div>
                <div class="row mt-3">
                    <div class="card">
                       
                        <div class="card-body">
                            {{ $stock->links('pagination::bootstrap-4') }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </main>
@endsection


@section('pageJs')
    <script type="text/javascript">
        $(".app-menu").removeClass("active");
        $("#nav_stocki").addClass("active");
        $("#stocki").addClass("is-expanded");
        $("#stocks").addClass("active");
        $(document).on('change', '#cat_id', function() {
            $.ajax({
                url: '{{ route('category.get') }}',
                type: 'GET',
                data: {
                    'p_category': $(this).val(),
                },
                success: function(data) {

                    $("#sub_cat_id").html(data);
                },
                error: function() {
                    swal("Warrning", "Error occured!", "error");
                },
            });
        });

        $("#type_id").change(function() {
            var type = $("#type_id").val();
            if (type == 1) {
                $("#by_category").show();
                $("#by_sub_category").hide();
                $("#by_unit").hide();
                $("#by_weight").hide();
                $("#by_qty").hide();
                $("#by_spi").hide();
                $("#by_cpi").hide();
                $("#by_location").hide();
            } 
            if (type == 2) {
                $("#by_category").show();
                $("#by_sub_category").show();
                $("#by_unit").hide();
                $("#by_weight").hide();
                $("#by_qty").hide();
                $("#by_spi").hide();
                $("#by_cpi").hide();
                $("#by_location").hide();

            }
            if (type == 3) {
                $("#by_category").hide();
                $("#by_sub_category").hide();
                $("#by_unit").show();
                $("#by_weight").hide();
                $("#by_qty").hide();
                $("#by_spi").hide();
                $("#by_cpi").hide();
                $("#by_location").hide();

            } 
            if (type == 4) {
                $("#by_category").hide();
                $("#by_sub_category").hide();
                $("#by_unit").hide();
                $("#by_weight").show();
                $("#by_qty").hide();
                $("#by_spi").hide();
                $("#by_cpi").hide();
                $("#by_location").hide();

            } 
            if (type == 5) {
                $("#by_category").hide();
                $("#by_sub_category").hide();
                $("#by_unit").hide();
                $("#by_weight").hide();
                $("#by_qty").show();
                $("#by_spi").hide();
                $("#by_cpi").hide();
                $("#by_location").hide();

            } 
            if (type == 6) {
                $("#by_category").hide();
                $("#by_sub_category").hide();
                $("#by_unit").hide();
                $("#by_weight").hide();
                $("#by_qty").hide();
                $("#by_spi").hide();
                $("#by_cpi").show();
                $("#by_location").hide();

            }
            if (type == 7) {
                $("#by_category").hide();
                $("#by_sub_category").hide();
                $("#by_unit").hide();
                $("#by_weight").hide();
                $("#by_qty").hide();
                $("#by_cpi").hide();
                $("#by_spi").show();
                $("#by_location").hide();

            }
            if (type == 8) {
                $("#by_category").hide();
                $("#by_sub_category").hide();
                $("#by_unit").hide();
                $("#by_weight").hide();
                $("#by_qty").hide();
                $("#by_cpi").hide();
                $("#by_spi").hide();
                $("#by_location").show();

            }
        });

      
    </script>
@endsection
